#!/bin/sh
# bouquet manager API

hexdec()
{
  hex=$1
  pos=1
  dec=0
  while [ "${hex#0}" != "$hex" ]
  do
    hex="${hex#0}"
  done
  while [ "$hex" != "" ]
  do
    nhex=${hex%?}
    nibble=$(eval echo ${hex#$nhex})
    hex="$nhex"
    [ "${nibble#a}" = "" ] && nibble=10
    [ "${nibble#b}" = "" ] && nibble=11
    [ "${nibble#c}" = "" ] && nibble=12
    [ "${nibble#d}" = "" ] && nibble=13
    [ "${nibble#e}" = "" ] && nibble=14
    [ "${nibble#f}" = "" ] && nibble=15
    dec=$((dec+nibble*pos))
    pos=$((pos*16))
  done
  echo $dec
}
WEBPORT=$(grep webifport /var/tuxbox/config/enigma/config)
WEBPORT="${WEBPORT#*=}"
if [ "$WEBPORT" = "" ]
then
  WEBPORT=80
else
  WEBPORT=$(hexdec $WEBPORT)
fi 
echo "WEB is on port $WEBPORT"
reloaduserbouquets()
{
  # reloads so that enigma gets the new status
  # this needs removing the http authentification
  wget -q -O /dev/null http://127.0.0.1:$WEBPORT/cgi-bin/reloadUserBouquets
}
listbouquets()
{
  # lists all file bouquets
  sed 's/.$//' /var/tuxbox/config/enigma/userbouquets.file.epl |
  while read line
  do
    if [ "${line#/}" != "$line" ]
    then
      sed -n 's/.$//
              s/^#NAME //p' "$line"
    fi 
  done
}
initbouquet()
{
  # initbouquet name
  # looks for file bouquet, if not exists, create empty one
if [ ! -f /var/tuxbox/config/enigma/userbouquets.file.epl ]
then
  # no file bouquets at all, initialize them
  bqnum=$$
  cat > /var/tuxbox/config/enigma/userbouquets.file.epl <<EOF
#NAME Bouquets (File)
#SERVICE: 4097:7:0:$bqnum:0:0:0:0:0:0:/var/tuxbox/config/enigma/userbouquet.$bqnum.file
#TYPE 16385
/var/tuxbox/config/enigma/userbouquet.$bqnum.file
EOF
  echo "#NAME $1
" > /var/tuxbox/config/enigma/userbouquet.$bqnum.file 
  file="/var/tuxbox/config/enigma/userbouquet.$bqnum.file"
  reloaduserbouquets
else
  found="no"
  for file in $(grep "^/" /var/tuxbox/config/enigma/userbouquets.file.epl|sed 's/.$//')
  do
    if [ "$(grep "^#NAME " "$file")" = "#NAME $1
" ]
    then
      found="yes"
      break
    fi
  done
  if [ "$found" = "no" ]
  then
    # bouquet not found, create empty one
    bqnum=$$
    while grep -q $bqnum.file /var/tuxbox/config/enigma/userbouquets.file.epl
    do
      bqnum=$((bqnum+1))
    done
    cat >> /var/tuxbox/config/enigma/userbouquets.file.epl <<EOF
#SERVICE: 4097:7:0:$bqnum:0:0:0:0:0:0:/var/tuxbox/config/enigma/userbouquet.$bqnum.file
#TYPE 16385
/var/tuxbox/config/enigma/userbouquet.$bqnum.file
EOF
    echo "#NAME $1
" > /var/tuxbox/config/enigma/userbouquet.$bqnum.file 
    file="/var/tuxbox/config/enigma/userbouquet.$bqnum.file"
    reloaduserbouquets
  fi
fi
#echo "bouquet $1 found: $file"
#cat "$file"
echo "$file"
}

delbouquet()
{
  # delbouquet filename 
  # remove matching bouquet
  bouquetslist="/var/tuxbox/config/enigma/userbouquets.file.epl"
  bqfile="$1"
  n="$2"
  i=0
  deleted="no"
  ffile=""
  fservice=""
  ftype=""
  while read line
  do
    line="$(echo "$line"|sed 's/.$//')"
    [ "${line%#NAME*}" = "" ] && echo "$line
" > "$bouquetslist"_n
    [ "${line%#SERVICE: *}" = "" ] && fservice="${line###SERVICE: }"
    [ "${line%#TYPE *}" = "" ] && ftype="${line###TYPE }"
    [ "${line#/}" != "$line" ] && ffile="$line" && i=$((i+1))
    if [ "${line#/}" != "$line" ] 
    then
      if [ "$ffile" != "$bqfile" ] 
      then
        echo "#SERVICE: $fservice
" >> "$bouquetslist"_n
        echo "#TYPE $ftype
" >> "$bouquetslist"_n
        echo "$ffile
" >> "$bouquetslist"_n
      else
        deleted="yes"
        rm "$ffile"
      fi 
      ffile=""
      fservice=""
      ftype=""
    fi
  done < "$bouquetslist" 
  mv "$bouquetslist"_n "$bouquetslist"
  reloaduserbouquets
}

getservice()
{
  # getservice filename N
  # gets Nth service from file
  # returns 0 (true) if found, 1 (false) if not found
  file="$1"
  n="$2"
  i=0
  found="no"
  SERVICE=""
  DESCRIPTION=""
  FILE=""
  while read line
  do
    line="$(echo "$line"|sed 's/.$//')"
    [ "${line%#NAME*}" = "" ] && NAME="${line###NAME }"
    [ "${line%#SERVICE: *}" = "" ] && SERVICE="${line###SERVICE: }"
    [ "${line%#DESCRIPTION: *}" = "" ] && DESCRIPTION="${line###DESCRIPTION: }"
    [ "${line#/}" != "$line" ] && FILE="$line" && i=$((i+1))
    if [ "$n" -eq "$i" ]
    then
      found="yes"
      break
    fi
    if [ "${line#/}" != "$line" ]
    then
      SERVICE=""
      DESCRIPTION=""
      FILE=""
    fi       
  done < "$file" 
  if [ "$found" = "no" ]
  then
    SERVICE=""
    DESCRIPTION=""
    FILE=""
    return 1
  else
    return 0
  fi
}

addservice()
{
  # addservice filename N
  # add service after position N
  # users variables:
  # FILE filename of the service
  # SERVICE (optional) in the form of #SERVICE: 1:0:1:6e47:431:1:c00000:0:0:0:path/file
  # DESCRIPTION (optional) name shown on screen
  if [ "${FILE#/}" = "$FILE" ]
  then
    FILE="$(pwd)/$FILE"
  fi 
  if [ "$SERVICE" = "" ]
  then
    SERVICE="1:0:0:0:0:0:0:0:0:0:$FILE"
  fi 
  file="$1"
  n="$2"
  if [ "$n" = "" ]
  then
    n=-1
  fi 
  i=0
  > "$file"_n
  added="no"
  while read line
  do
#    [ "${line%#NAME*}" = "" ] && echo "$line" >> "$file"_n
    if [ "$n" -eq "$i" ]
    then
      echo "#SERVICE: $SERVICE
" >> "$file"_n
      [ "$DESCRIPTION" != "" ] && echo "#DESCRIPTION: $DESCRIPTION
" >> "$file"_n
      echo "$FILE
" >> "$file"_n
      added="yes"
    fi
    echo "$line" >> "$file"_n
    [ "${line#/}" != "$line" ] && i=$((i+1))
  done < "$file"
  if [ "$added" = "no" ]
  then
    echo "#SERVICE: $SERVICE
" >> "$file"_n
    [ "$DESCRIPTION" != "" ] && echo "#DESCRIPTION: $DESCRIPTION
" >> "$file"_n
    echo "$FILE
" >> "$file"_n
  fi
  mv "$file"_n "$file"
  reloaduserbouquets
}

delservice()
{
  # delservice filename 
  # remove matching service 
  file="$1"
  n="$2"
  i=0
  deleted="no"
  ffile=""
  fservice=""
  fdescription=""
  while read line
  do
    line="$(echo "$line"|sed 's/.$//')"
    [ "${line%#NAME*}" = "" ] && echo "$line
" > "$file"_n
    [ "${line%#SERVICE: *}" = "" ] && fservice="${line###SERVICE: }"
    [ "${line%#DESCRIPTION: *}" = "" ] && fdescription="${line###DESCRIPTION: }"
    [ "${line#/}" != "$line" ] && ffile="$line" && i=$((i+1))
    if [ "${line#/}" != "$line" ] 
    then
      if [ "$ffile" != "$FILE" ] ||
         [ "$fservice" != "$SERVICE" ] ||
         [ "$fdescription" != "$DESCRIPTION" ] 
      then
        echo "#SERVICE: $fservice
" >> "$file"_n
        [ "$fdescription" != "" ] && echo "#DESCRIPTION: $fdescription
" >> "$file"_n
        echo "$ffile
" >> "$file"_n
      else
        deleted="yes"
      fi 
      ffile=""
      fservice=""
      fdescription=""
    fi
  done < "$file" 
  mv "$file"_n "$file"
  reloaduserbouquets
}

